@@ -269,8 +269,6 @@ void                nautilus_files_view_activate_file                    (Nautil
 void                nautilus_files_view_preview_files                    (NautilusFilesView *view,
                                                                           GList             *files,
                                                                           GArray            *locations);
-void                nautilus_files_view_preview_update                   (NautilusFilesView *view,
-                                                                          GList             *files);
 void                nautilus_files_view_start_batching_selection_changes (NautilusFilesView *view);
 void                nautilus_files_view_stop_batching_selection_changes  (NautilusFilesView *view);
 void                nautilus_files_view_notify_selection_changed         (NautilusFilesView *view);
@@ -293,8 +291,6 @@ void                nautilus_files_view_remove_subdirectory             (Nautilu
 gboolean            nautilus_files_view_is_editable              (NautilusFilesView      *view);
 NautilusWindow *    nautilus_files_view_get_window               (NautilusFilesView      *view);
 
-guint               nautilus_files_view_get_view_id                (NautilusView      *view);
-
 /* file operations */
 char *            nautilus_files_view_get_backing_uri            (NautilusFilesView      *view);
 void              nautilus_files_view_move_copy_items            (NautilusFilesView      *view,
