@@ -32,9 +32,11 @@
 
 typedef struct
 {
+    gboolean waiting_for_data;
     gboolean have_data;
     gboolean have_valid_data;
 
+    gboolean is_hover;
     gboolean drop_occurred;
 
     unsigned int info;
@@ -169,6 +171,8 @@ slot_proxy_drag_motion (GtkWidget      *widget,
 
     drag_info = user_data;
 
+    drag_info->is_hover = TRUE;
+
     action = 0;
     valid_text_drag = FALSE;
     valid_xds_drag = FALSE;
@@ -181,7 +185,7 @@ slot_proxy_drag_motion (GtkWidget      *widget,
     window = gtk_widget_get_toplevel (widget);
     g_assert (NAUTILUS_IS_WINDOW (window));
 
-    if (!drag_info->have_data)
+    if (!drag_info->have_data && !drag_info->waiting_for_data)
     {
         target = gtk_drag_dest_find_target (widget, context, NULL);
 
@@ -190,6 +194,7 @@ slot_proxy_drag_motion (GtkWidget      *widget,
             goto out;
         }
 
+        drag_info->waiting_for_data = TRUE;
         gtk_drag_get_data (widget, context, target, time);
     }
 
@@ -333,6 +338,7 @@ slot_proxy_drag_leave (GtkWidget      *widget,
 
     drag_info = user_data;
 
+    drag_info->is_hover = FALSE;
     gtk_drag_unhighlight (widget);
     drag_info_clear (drag_info);
 }
@@ -353,8 +359,12 @@ slot_proxy_drag_drop (GtkWidget      *widget,
 
     drag_info->drop_occurred = TRUE;
 
-    target = gtk_drag_dest_find_target (widget, context, NULL);
-    gtk_drag_get_data (widget, context, target, time);
+    if (!drag_info->waiting_for_data)
+    {
+        target = gtk_drag_dest_find_target (widget, context, NULL);
+        drag_info->waiting_for_data = TRUE;
+        gtk_drag_get_data (widget, context, target, time);
+    }
 
     return TRUE;
 }
@@ -466,16 +476,28 @@ slot_proxy_drag_data_received (GtkWidget        *widget,
     drag_info = user_data;
 
     g_assert (!drag_info->have_data);
+    drag_info->waiting_for_data = FALSE;
 
-    drag_info->have_data = TRUE;
-    drag_info->info = info;
+    if (!drag_info->is_hover && !drag_info->drop_occurred)
+    {
+        /* Ignore data arriving after ::drag-leave, except if followed by
+         * ::drag-drop. */
+        return;
+    }
 
     if (gtk_selection_data_get_length (data) < 0)
     {
-        drag_info->have_valid_data = FALSE;
+        /* Data retrieval failed. */
+        if (drag_info->drop_occurred)
+        {
+            gtk_drag_finish (context, FALSE, FALSE, time);
+        }
         return;
     }
 
+    drag_info->have_data = TRUE;
+    drag_info->info = info;
+
     if (info == NAUTILUS_ICON_DND_GNOME_ICON_LIST)
     {
         drag_info->data.selection_list = nautilus_drag_build_selection_list (data);
